@@ -220,11 +220,22 @@ class Leftronic(object):
                                                 dataRows))
 
     def populateTable(self, streamName, headerRow, dataRows):
+        """ Formats table as a dict """
         dataRows.insert(0, headerRow)
         point = {'table': dataRows}
         return {'streamName': streamName,
                 'point': point}
 
+    def pushHtml(self, streamName, htmlData):
+        """ Pushes HTML to an HTML widget """
+        return self.postData(self.populateHtml(streamName,
+                                               htmlData))
+
+    def populateHtml(self, streamName, htmlData):
+        """ Formats HTML as a dict """
+        return {'streamName': streamName,
+                'point': {'html': htmlData}}
+
     def clear(self, streamName):
         parameters = {'streamName': streamName,
                       'command': 'clear'}
@@ -282,5 +293,3 @@ class Leftronic(object):
 
             parameters['epoint'] = self.encryptText(json.dumps(parameters['point']))
             del parameters['point']
-
-
